==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/WebAclRuleActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.WebAclRuleActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type Specifies how you want AWS WAF to respond to requests that don't match the criteria in any of the `rules`.
 * e.g., `ALLOW` or `BLOCK`
 */
public data class WebAclRuleActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.WebAclRuleActionArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.WebAclRuleActionArgs =
        com.pulumi.aws.waf.inputs.WebAclRuleActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value Specifies how you want AWS WAF to respond to requests that don't match the criteria in any of the `rules`.
     * e.g., `ALLOW` or `BLOCK`
     */
    @JvmName("glvwqddssxwwqaha")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies how you want AWS WAF to respond to requests that don't match the criteria in any of the `rules`.
     * e.g., `ALLOW` or `BLOCK`
     */
    @JvmName("hpfancrvcwbirxfa")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleActionArgs = WebAclRuleActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/waf/kotlin/inputs/WebAclRuleActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.waf.kotlin.inputs

import com.pulumi.aws.waf.inputs.WebAclRuleActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type valid values are: `BLOCK`, `ALLOW`, or `COUNT`
 */
public data class WebAclRuleActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.waf.inputs.WebAclRuleActionArgs> {
    override fun toJava(): com.pulumi.aws.waf.inputs.WebAclRuleActionArgs =
        com.pulumi.aws.waf.inputs.WebAclRuleActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value valid values are: `BLOCK`, `ALLOW`, or `COUNT`
     */
    @JvmName("bkeobgeeahcrocwg")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value valid values are: `BLOCK`, `ALLOW`, or `COUNT`
     */
    @JvmName("cysihyulluddkhsp")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleActionArgs = WebAclRuleActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
